@@ -4,7 +4,6 @@
 #### Tsagris Michail 06/2014
 #### mtsagris@yahoo.gr
 ################################
-
 kent.datacontour <- function(x) {
   ## u contains the data in latitude and longitude
   ## the first column is the latitude and the
@@ -25,7 +24,6 @@ kent.datacontour <- function(x) {
   G <- a$G ## G matrix, the mean direction and the major-minor axes
   k <- a$para[1] ## kappa, concentration parameter
   b <- a$para[2] ## beta, ovalness
-
   gam <- c(0, k, 0)
   lam <- c(0, -b, b)
   ckb <- fb.saddle(gam, lam)[3] ## logarithm of the normalising constant
@@ -39,14 +37,10 @@ kent.datacontour <- function(x) {
       y <- euclid( c(x1[i], x2[j]) )
       can <-  -ckb + k * y %*% G[, 1] + b * (y %*% G[, 2])^2 -
         b * (y %*% G[, 3])^2
-      if ( abs(exp( can) ) < Inf ) {
-        mat[i, j] <- exp(can)
-      } else  mat[i, j] <- NA
+      if ( abs(exp( can) ) < Inf )  mat[i, j] <- exp(can)
     }
   }
 
-  contour(x1, x2, mat, nlevels = 10, col = 2, xlab = "Latitude",
-          ylab = "Longitude")
+  contour(x1, x2, mat, nlevels = 10, col = 2, xlab = "Latitude", ylab = "Longitude")
   points(u[, 1], u[, 2])
-
 }
